@@ -8,11 +8,17 @@ and Open XML.
 import platform
 
 
-class _BaseLength(int):
-    """Base class for length classes Inches, Cm, Mm, Px, and Emu."""
+class BaseLength(int):
+    """
+    Base class for length classes Inches, Emu, Cm, Mm, Pt, and Px. Provides
+    properties for converting length values to convenient units.
+    """
+
     _EMUS_PER_INCH = 914400
+    _EMUS_PER_CENTIPOINT = 127
     _EMUS_PER_CM = 360000
     _EMUS_PER_MM = 36000
+    _EMUS_PER_PT = 12700
     _EMUS_PER_PX = 9525 if platform.system() == 'Windows' else 12700
 
     def __new__(cls, emu):
@@ -20,68 +26,119 @@ class _BaseLength(int):
 
     @property
     def inches(self):
+        """
+        Floating point length in inches
+        """
         return self / float(self._EMUS_PER_INCH)
 
+    @property
+    def centipoints(self):
+        """
+        Integer length in hundredths of a point (1/7200 inch). Used
+        internally because PowerPoint stores font size in centipoints.
+        """
+        return self / self._EMUS_PER_CENTIPOINT
+
     @property
     def cm(self):
+        """
+        Floating point length in centimeters
+        """
         return self / float(self._EMUS_PER_CM)
 
+    @property
+    def emu(self):
+        """
+        Integer length in English Metric Units
+        """
+        return self
+
     @property
     def mm(self):
+        """
+        Floating point length in millimeters
+        """
         return self / float(self._EMUS_PER_MM)
 
+    @property
+    def pt(self):
+        """
+        Floating point length in points
+        """
+        return self / float(self._EMUS_PER_PT)
+
     @property
     def px(self):
+        """
+        Integer length in pixels. Note this value is platform dependent,
+        using 96 pixels/inch on Windows, 72 pixels/inch on all other
+        platforms.
+        """
         # round can somtimes return values like x.999999 which are truncated
         # to x by int(); adding the 0.1 prevents this
         return int(round(self / float(self._EMUS_PER_PX)) + 0.1)
 
-    @property
-    def emu(self):
-        return self
 
-
-class Inches(_BaseLength):
-    """Convenience constructor for length in inches."""
+class Inches(BaseLength):
+    """
+    Convenience constructor for length in inches
+    """
     def __new__(cls, inches):
-        emu = int(inches * _BaseLength._EMUS_PER_INCH)
-        return _BaseLength.__new__(cls, emu)
+        emu = int(inches * BaseLength._EMUS_PER_INCH)
+        return BaseLength.__new__(cls, emu)
 
 
-class Cm(_BaseLength):
-    """Convenience constructor for length in centimeters."""
+class Centipoints(BaseLength):
+    """
+    Convenience constructor for length in hundredths of a point
+    """
+    def __new__(cls, centipoints):
+        emu = int(centipoints * BaseLength._EMUS_PER_CENTIPOINT)
+        return BaseLength.__new__(cls, emu)
+
+
+class Cm(BaseLength):
+    """
+    Convenience constructor for length in centimeters
+    """
     def __new__(cls, cm):
-        emu = int(cm * _BaseLength._EMUS_PER_CM)
-        return _BaseLength.__new__(cls, emu)
+        emu = int(cm * BaseLength._EMUS_PER_CM)
+        return BaseLength.__new__(cls, emu)
 
 
-class Emu(_BaseLength):
-    """Convenience constructor for length in english metric units."""
+class Emu(BaseLength):
+    """
+    Convenience constructor for length in english metric units
+    """
     def __new__(cls, emu):
-        return _BaseLength.__new__(cls, int(emu))
+        return BaseLength.__new__(cls, int(emu))
 
 
-class Mm(_BaseLength):
-    """Convenience constructor for length in millimeters."""
+class Mm(BaseLength):
+    """
+    Convenience constructor for length in millimeters
+    """
     def __new__(cls, mm):
-        emu = int(mm * _BaseLength._EMUS_PER_MM)
-        return _BaseLength.__new__(cls, emu)
+        emu = int(mm * BaseLength._EMUS_PER_MM)
+        return BaseLength.__new__(cls, emu)
 
 
-class Pt(int):
-    """Convenience class for setting font sizes in points"""
-    _UNITS_PER_POINT = 100
-
-    def __new__(cls, pts):
-        units = int(pts * Pt._UNITS_PER_POINT)
-        return int.__new__(cls, units)
+class Pt(BaseLength):
+    """
+    Convenience value class for specifying a length in points
+    """
+    def __new__(cls, points):
+        emu = int(points * BaseLength._EMUS_PER_PT)
+        return BaseLength.__new__(cls, emu)
 
 
-class Px(_BaseLength):
-    """Convenience constructor for length in pixels."""
+class Px(BaseLength):
+    """
+    Convenience constructor for length in pixels
+    """
     def __new__(cls, px):
-        emu = int(px * _BaseLength._EMUS_PER_PX)
-        return _BaseLength.__new__(cls, emu)
+        emu = int(px * BaseLength._EMUS_PER_PX)
+        return BaseLength.__new__(cls, emu)
 
 
 class Collection(object):
